@@ -7,6 +7,7 @@ from enum import Enum, auto
 from typing import Any, Dict
 
 import cloudscraper
+import cfscrape
 
 logger = logging.getLogger(__name__)
 
@@ -53,14 +54,16 @@ class ApiClient:
         try:
             response = self.session.get(url, headers=total_headers, params=params)
             response.raise_for_status()
+            logger.debug("Response: %s", response.content)
             return response
         except Exception as err:
+            logger.debug("Response in exception: %s", response.content)
             if response.status_code == 429:
                 raise GarminConnectTooManyRequestsError("Too many requests") from err
             if response.status_code == 401:
                 raise GarminConnectAuthenticationError("Authentication error") from err
             if response.status_code == 403:
-                self.login()
+                raise GarminConnectConnectionError(f"Forbidden url: {url}") from err
 
             raise GarminConnectConnectionError(err) from err
 
@@ -80,12 +83,16 @@ class ApiClient:
                 url, headers=total_headers, params=params, data=data
             )
             response.raise_for_status()
+            logger.debug("Response: %s", response.content)
             return response
         except Exception as err:
+            logger.debug("Response in exception: %s", response.content)
             if response.status_code == 429:
                 raise GarminConnectTooManyRequestsError("Too many requests") from err
             if response.status_code == 401:
                 raise GarminConnectAuthenticationError("Authentication error") from err
+            if response.status_code == 403:
+                raise GarminConnectConnectionError(f"Forbidden url: {url}") from err
 
             raise GarminConnectConnectionError(err) from err
 
@@ -162,7 +169,8 @@ class Garmin:
 
         self.garmin_headers = {"NK": "NT"}
 
-        self.session = cloudscraper.CloudScraper()
+        # self.session = cloudscraper.CloudScraper()
+        self.session = cfscrape.create_scraper()
         self.sso_rest_client = ApiClient(
             self.session,
             self.garmin_connect_sso_url,
